@@ -85,7 +85,7 @@ void DecorationButtonTest::testButton()
     QCOMPARE(button.geometry(), QRectF());
 
     // test setting the geometry
-    QSignalSpy geometryChangedSpy(&button, SIGNAL(geometryChanged(QRectF)));
+    QSignalSpy geometryChangedSpy(&button, &KDecoration2::DecorationButton::geometryChanged);
     QVERIFY(geometryChangedSpy.isValid());
     // setting to default geometry shouldn't change
     button.setGeometry(QRectF());
@@ -100,7 +100,7 @@ void DecorationButtonTest::testButton()
     QCOMPARE(geometryChangedSpy.first().first().toRectF(), testGeometry);
 
     // test changing visibility
-    QSignalSpy visibilityChangedSpy(&button, SIGNAL(visibilityChanged(bool)));
+    QSignalSpy visibilityChangedSpy(&button, &KDecoration2::DecorationButton::visibilityChanged);
     QVERIFY(visibilityChangedSpy.isValid());
     button.setVisible(true);
     QCOMPARE(visibilityChangedSpy.count(), 0);
@@ -119,14 +119,14 @@ void DecorationButtonTest::testChecked()
     button.setGeometry(QRect(0, 0, 10, 10));
 
     // without being checkable it should not get checked
-    QSignalSpy checkedChangedSpy(&button, SIGNAL(checkedChanged(bool)));
+    QSignalSpy checkedChangedSpy(&button, &KDecoration2::DecorationButton::checkedChanged);
     QVERIFY(checkedChangedSpy.isValid());
     button.setChecked(true);
     QCOMPARE(button.isChecked(), false);
     QCOMPARE(checkedChangedSpy.count(), 0);
 
     // now let's set the checkable state
-    QSignalSpy checkableChangedSpy(&button, SIGNAL(checkableChanged(bool)));
+    QSignalSpy checkableChangedSpy(&button, &KDecoration2::DecorationButton::checkableChanged);
     QVERIFY(checkableChangedSpy.isValid());
     // setting to same should not emit
     button.setCheckable(false);
@@ -173,7 +173,7 @@ void DecorationButtonTest::testEnabled()
     button.setGeometry(QRect(0, 0, 10, 10));
 
     // enabling has influence on whether the button accepts events, so we need to fake events
-    QSignalSpy enabledChangedSpy(&button, SIGNAL(enabledChanged(bool)));
+    QSignalSpy enabledChangedSpy(&button, &KDecoration2::DecorationButton::enabledChanged);
     QVERIFY(enabledChangedSpy.isValid());
     // setting to same shouldn't change
     button.setEnabled(true);
@@ -184,7 +184,7 @@ void DecorationButtonTest::testEnabled()
     QCOMPARE(enabledChangedSpy.first().first().toBool(), false);
 
     // now let's send it a hover entered event
-    QSignalSpy hoveredChangedSpy(&button, SIGNAL(hoveredChanged(bool)));
+    QSignalSpy hoveredChangedSpy(&button, &KDecoration2::DecorationButton::hoveredChanged);
     QVERIFY(hoveredChangedSpy.isValid());
     QHoverEvent event(QEvent::HoverEnter, QPointF(1, 1), QPointF(-1, -1));
     event.setAccepted(false);
@@ -230,9 +230,9 @@ void DecorationButtonTest::testPressIgnore()
     MockButton button(KDecoration2::DecorationButtonType::Custom, &mockDecoration);
     button.setGeometry(QRect(0, 0, 10, 10));
     button.setAcceptedButtons(Qt::LeftButton);
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QFETCH(bool, enabled);
@@ -278,11 +278,11 @@ void DecorationButtonTest::testReleaseIgnore()
     button.setAcceptedButtons(Qt::LeftButton);
     button.setEnabled(true);
     button.setVisible(true);
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPoint(0, 0), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -331,9 +331,9 @@ void DecorationButtonTest::testHoverEnterIgnore()
     // create a custom button and verify the base settings
     MockButton button(KDecoration2::DecorationButtonType::Custom, &mockDecoration);
     button.setGeometry(QRect(0, 0, 10, 10));
-    QSignalSpy pointerEnteredSpy(&button, SIGNAL(pointerEntered()));
+    QSignalSpy pointerEnteredSpy(&button, &KDecoration2::DecorationButton::pointerEntered);
     QVERIFY(pointerEnteredSpy.isValid());
-    QSignalSpy hoveredChangedSpy(&button, SIGNAL(hoveredChanged(bool)));
+    QSignalSpy hoveredChangedSpy(&button, &KDecoration2::DecorationButton::hoveredChanged);
     QVERIFY(hoveredChangedSpy.isValid());
 
     QFETCH(bool, enabled);
@@ -382,11 +382,11 @@ void DecorationButtonTest::testHoverLeaveIgnore()
     button.setGeometry(QRect(0, 0, 10, 10));
     button.setEnabled(true);
     button.setVisible(true);
-    QSignalSpy pointerEnteredSpy(&button, SIGNAL(pointerEntered()));
+    QSignalSpy pointerEnteredSpy(&button, &KDecoration2::DecorationButton::pointerEntered);
     QVERIFY(pointerEnteredSpy.isValid());
-    QSignalSpy hoveredChangedSpy(&button, SIGNAL(hoveredChanged(bool)));
+    QSignalSpy hoveredChangedSpy(&button, &KDecoration2::DecorationButton::hoveredChanged);
     QVERIFY(hoveredChangedSpy.isValid());
-    QSignalSpy pointerLeavedSpy(&button, SIGNAL(pointerLeft()));
+    QSignalSpy pointerLeavedSpy(&button, &KDecoration2::DecorationButton::pointerLeft);
     QVERIFY(pointerLeavedSpy.isValid());
 
     QHoverEvent enterEvent(QEvent::HoverEnter, QPoint(0, 0), QPoint());
@@ -423,11 +423,11 @@ void DecorationButtonTest::testHover()
     button.setGeometry(QRectF(0, 0, 10, 10));
     button.setEnabled(true);
     button.setVisible(true);
-    QSignalSpy pointerEnteredSpy(&button, SIGNAL(pointerEntered()));
+    QSignalSpy pointerEnteredSpy(&button, &KDecoration2::DecorationButton::pointerEntered);
     QVERIFY(pointerEnteredSpy.isValid());
-    QSignalSpy hoveredChangedSpy(&button, SIGNAL(hoveredChanged(bool)));
+    QSignalSpy hoveredChangedSpy(&button, &KDecoration2::DecorationButton::hoveredChanged);
     QVERIFY(hoveredChangedSpy.isValid());
-    QSignalSpy pointerLeavedSpy(&button, SIGNAL(pointerLeft()));
+    QSignalSpy pointerLeavedSpy(&button, &KDecoration2::DecorationButton::pointerLeft);
     QVERIFY(pointerLeavedSpy.isValid());
 
     QHoverEvent enterEvent(QEvent::HoverEnter, QPoint(0, 0), QPoint());
@@ -479,9 +479,9 @@ void DecorationButtonTest::testMouseMove()
     button.setGeometry(QRectF(0, 0, 10, 10));
     button.setEnabled(true);
     button.setVisible(true);
-    QSignalSpy hoveredChangedSpy(&button, SIGNAL(hoveredChanged(bool)));
+    QSignalSpy hoveredChangedSpy(&button, &KDecoration2::DecorationButton::hoveredChanged);
     QVERIFY(hoveredChangedSpy.isValid());
-    QSignalSpy pointerLeavedSpy(&button, SIGNAL(pointerLeft()));
+    QSignalSpy pointerLeavedSpy(&button, &KDecoration2::DecorationButton::pointerLeft);
     QVERIFY(pointerLeavedSpy.isValid());
 
     QHoverEvent enterEvent(QEvent::HoverEnter, QPoint(0, 0), QPoint());
@@ -529,7 +529,7 @@ void DecorationButtonTest::testClose()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // if the client is closeable the button should get enabled
-    QSignalSpy closeableChangedSpy(mockDecoration.client().data(), SIGNAL(closeableChanged(bool)));
+    QSignalSpy closeableChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::closeableChanged);
     QVERIFY(closeableChangedSpy.isValid());
     client->setCloseable(true);
     QCOMPARE(button.isEnabled(), true);
@@ -537,15 +537,15 @@ void DecorationButtonTest::testClose()
     QCOMPARE(closeableChangedSpy.first().first().toBool(), true);
 
     // clicking the button should trigger a request for close
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy closeRequestedSpy(client, SIGNAL(closeRequested()));
+    QSignalSpy closeRequestedSpy(client, &MockClient::closeRequested);
     QVERIFY(closeRequestedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -590,7 +590,7 @@ void DecorationButtonTest::testMinimize()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // if the client is minimizeable the button should get enabled
-    QSignalSpy minimizableChangedSpy(mockDecoration.client().data(), SIGNAL(minimizeableChanged(bool)));
+    QSignalSpy minimizableChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::minimizeableChanged);
     QVERIFY(minimizableChangedSpy.isValid());
     client->setMinimizable(true);
     QCOMPARE(button.isEnabled(), true);
@@ -598,15 +598,15 @@ void DecorationButtonTest::testMinimize()
     QCOMPARE(minimizableChangedSpy.first().first().toBool(), true);
 
     // clicking the button should trigger a request for minimize
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy minimizeRequestedSpy(client, SIGNAL(minimizeRequested()));
+    QSignalSpy minimizeRequestedSpy(client, &MockClient::minimizeRequested);
     QVERIFY(minimizeRequestedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -651,7 +651,7 @@ void DecorationButtonTest::testQuickHelp()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // if the client provides quickhelp the button should get enabled
-    QSignalSpy providesContextHelpChangedSpy(mockDecoration.client().data(), SIGNAL(providesContextHelpChanged(bool)));
+    QSignalSpy providesContextHelpChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::providesContextHelpChanged);
     QVERIFY(providesContextHelpChangedSpy.isValid());
     client->setProvidesContextHelp(true);
     QCOMPARE(button.isVisible(), true);
@@ -659,15 +659,15 @@ void DecorationButtonTest::testQuickHelp()
     QCOMPARE(providesContextHelpChangedSpy.first().first().toBool(), true);
 
     // clicking the button should trigger a request for minimize
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy quickhelpRequestedSpy(client, SIGNAL(quickHelpRequested()));
+    QSignalSpy quickhelpRequestedSpy(client, &MockClient::quickHelpRequested);
     QVERIFY(quickhelpRequestedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -711,15 +711,15 @@ void DecorationButtonTest::testKeepAbove()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // clicking the button should trigger a request for keep above changed
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy keepAboveChangedSpy(mockDecoration.client().data(), SIGNAL(keepAboveChanged(bool)));
+    QSignalSpy keepAboveChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::keepAboveChanged);
     QVERIFY(keepAboveChangedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -774,15 +774,15 @@ void DecorationButtonTest::testKeepBelow()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // clicking the button should trigger a request for keep above changed
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy keepBelowChangedSpy(mockDecoration.client().data(), SIGNAL(keepBelowChanged(bool)));
+    QSignalSpy keepBelowChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::keepBelowChanged);
     QVERIFY(keepBelowChangedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -838,7 +838,7 @@ void DecorationButtonTest::testShade()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // if the client is shadeable the button should get enabled
-    QSignalSpy shadeableChangedSpy(mockDecoration.client().data(), SIGNAL(shadeableChanged(bool)));
+    QSignalSpy shadeableChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::shadeableChanged);
     QVERIFY(shadeableChangedSpy.isValid());
     client->setShadeable(true);
     QCOMPARE(button.isEnabled(), true);
@@ -846,15 +846,15 @@ void DecorationButtonTest::testShade()
     QCOMPARE(shadeableChangedSpy.first().first().toBool(), true);
 
     // clicking the button should trigger a request for keep above changed
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy shadedChangedSpy(mockDecoration.client().data(), SIGNAL(shadedChanged(bool)));
+    QSignalSpy shadedChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::shadedChanged);
     QVERIFY(shadedChangedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -910,7 +910,7 @@ void DecorationButtonTest::testMaximize()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton | Qt::MiddleButton | Qt::RightButton);
 
     // if the client is maximizable the button should get enabled
-    QSignalSpy maximizableChangedSpy(mockDecoration.client().data(), SIGNAL(maximizeableChanged(bool)));
+    QSignalSpy maximizableChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::maximizeableChanged);
     QVERIFY(maximizableChangedSpy.isValid());
     client->setMaximizable(true);
     QCOMPARE(button.isEnabled(), true);
@@ -918,19 +918,19 @@ void DecorationButtonTest::testMaximize()
     QCOMPARE(maximizableChangedSpy.first().first().toBool(), true);
 
     // clicking the button should trigger a request for keep above changed
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy maximizedChangedSpy(mockDecoration.client().data(), SIGNAL(maximizedChanged(bool)));
+    QSignalSpy maximizedChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::maximizedChanged);
     QVERIFY(maximizedChangedSpy.isValid());
-    QSignalSpy maximizedVerticallyChangedSpy(mockDecoration.client().data(), SIGNAL(maximizedVerticallyChanged(bool)));
+    QSignalSpy maximizedVerticallyChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::maximizedVerticallyChanged);
     QVERIFY(maximizedVerticallyChangedSpy.isValid());
-    QSignalSpy maximizedHorizontallyChangedSpy(mockDecoration.client().data(), SIGNAL(maximizedHorizontallyChanged(bool)));
+    QSignalSpy maximizedHorizontallyChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::maximizedHorizontallyChanged);
     QVERIFY(maximizedHorizontallyChangedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent leftPressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -1025,9 +1025,9 @@ void DecorationButtonTest::testOnAllDesktops()
     MockSettings *settings = bridge.lastCreatedSettings();
     QVERIFY(settings);
 
-    QSignalSpy onAllDesktopsAvailableChangedSpy(decoSettings.data(), SIGNAL(onAllDesktopsAvailableChanged(bool)));
+    QSignalSpy onAllDesktopsAvailableChangedSpy(decoSettings.data(), &KDecoration2::DecorationSettings::onAllDesktopsAvailableChanged);
     QVERIFY(onAllDesktopsAvailableChangedSpy.isValid());
-    QSignalSpy visibleChangedSpy(&button, SIGNAL(visibilityChanged(bool)));
+    QSignalSpy visibleChangedSpy(&button, &KDecoration2::DecorationButton::visibilityChanged);
     QVERIFY(visibleChangedSpy.isValid());
 
     settings->setOnAllDesktopsAvailabe(true);
@@ -1037,15 +1037,15 @@ void DecorationButtonTest::testOnAllDesktops()
     QCOMPARE(visibleChangedSpy.last().first().toBool(), true);
 
     // clicking the button should trigger a request for on all desktops
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy onAllDesktopsChangedSpy(mockDecoration.client().data(), SIGNAL(onAllDesktopsChanged(bool)));
+    QSignalSpy onAllDesktopsChangedSpy(mockDecoration.client().data(), &KDecoration2::DecoratedClient::onAllDesktopsChanged);
     QVERIFY(onAllDesktopsChangedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -1094,15 +1094,15 @@ void DecorationButtonTest::testMenu()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton | Qt::RightButton);
 
     // clicking the button should trigger a request for menu button
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
-    QSignalSpy menuRequestedSpy(client, SIGNAL(menuRequested()));
+    QSignalSpy menuRequestedSpy(client, &MockClient::menuRequested);
     QVERIFY(menuRequestedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -1144,7 +1144,7 @@ void DecorationButtonTest::testMenuDoubleClick()
 
     MockSettings *settings = bridge.lastCreatedSettings();
     QVERIFY(settings);
-    QSignalSpy closeOnDoubleClickOnMenuChangedSpy(decoSettings.data(), SIGNAL(closeOnDoubleClickOnMenuChanged(bool)));
+    QSignalSpy closeOnDoubleClickOnMenuChangedSpy(decoSettings.data(), &KDecoration2::DecorationSettings::closeOnDoubleClickOnMenuChanged);
     QVERIFY(closeOnDoubleClickOnMenuChangedSpy.isValid());
     settings->setCloseOnDoubleClickOnMenu(true);
     QCOMPARE(closeOnDoubleClickOnMenuChangedSpy.count(), 1);
@@ -1153,13 +1153,13 @@ void DecorationButtonTest::testMenuDoubleClick()
     // button used a queued connection, so we need to run event loop
     QCoreApplication::processEvents();
 
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy doubleClickedSpy(&button, SIGNAL(doubleClicked()));
+    QSignalSpy doubleClickedSpy(&button, &KDecoration2::DecorationButton::doubleClicked);
     QVERIFY(doubleClickedSpy.isValid());
-    QSignalSpy closeRequestedSpy(client, SIGNAL(closeRequested()));
+    QSignalSpy closeRequestedSpy(client, &MockClient::closeRequested);
     QVERIFY(closeRequestedSpy.isValid());
-    QSignalSpy menuRequestedSpy(client, SIGNAL(menuRequested()));
+    QSignalSpy menuRequestedSpy(client, &MockClient::menuRequested);
     QVERIFY(menuRequestedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
@@ -1228,7 +1228,7 @@ void DecorationButtonTest::testMenuPressAndHold()
 
     MockSettings *settings = bridge.lastCreatedSettings();
     QVERIFY(settings);
-    QSignalSpy closeOnDoubleClickOnMenuChangedSpy(decoSettings.data(), SIGNAL(closeOnDoubleClickOnMenuChanged(bool)));
+    QSignalSpy closeOnDoubleClickOnMenuChangedSpy(decoSettings.data(), &KDecoration2::DecorationSettings::closeOnDoubleClickOnMenuChanged);
     QVERIFY(closeOnDoubleClickOnMenuChangedSpy.isValid());
     settings->setCloseOnDoubleClickOnMenu(true);
     QCOMPARE(closeOnDoubleClickOnMenuChangedSpy.count(), 1);
@@ -1237,13 +1237,13 @@ void DecorationButtonTest::testMenuPressAndHold()
     // button used a queued connection, so we need to run event loop
     QCoreApplication::processEvents();
 
-    QSignalSpy menuRequestedSpy(client, SIGNAL(menuRequested()));
+    QSignalSpy menuRequestedSpy(client, &MockClient::menuRequested);
     QVERIFY(menuRequestedSpy.isValid());
-    QSignalSpy doubleClickedSpy(&button, SIGNAL(doubleClicked()));
+    QSignalSpy doubleClickedSpy(&button, &KDecoration2::DecorationButton::doubleClicked);
     QVERIFY(doubleClickedSpy.isValid());
-    QSignalSpy closeRequestedSpy(client, SIGNAL(closeRequested()));
+    QSignalSpy closeRequestedSpy(client, &MockClient::closeRequested);
     QVERIFY(closeRequestedSpy.isValid());
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
 
     // send a press event
@@ -1306,15 +1306,15 @@ void DecorationButtonTest::testApplicationMenu()
     QCOMPARE(button.acceptedButtons(), Qt::LeftButton);
 
     // clicking the button should trigger a request for application menu
-    QSignalSpy clickedSpy(&button, SIGNAL(clicked(Qt::MouseButton)));
+    QSignalSpy clickedSpy(&button, &KDecoration2::DecorationButton::clicked);
     QVERIFY(clickedSpy.isValid());
-    QSignalSpy pressedSpy(&button, SIGNAL(pressed()));
+    QSignalSpy pressedSpy(&button, &KDecoration2::DecorationButton::pressed);
     QVERIFY(pressedSpy.isValid());
-    QSignalSpy releasedSpy(&button, SIGNAL(released()));
+    QSignalSpy releasedSpy(&button, &KDecoration2::DecorationButton::released);
     QVERIFY(releasedSpy.isValid());
-    QSignalSpy pressedChangedSpy(&button, SIGNAL(pressedChanged(bool)));
+    QSignalSpy pressedChangedSpy(&button, &KDecoration2::DecorationButton::pressedChanged);
     QVERIFY(pressedChangedSpy.isValid());
-    QSignalSpy applicationMenuRequestedSpy(client, SIGNAL(applicationMenuRequested()));
+    QSignalSpy applicationMenuRequestedSpy(client, &MockClient::applicationMenuRequested);
     QVERIFY(applicationMenuRequestedSpy.isValid());
 
     QMouseEvent pressEvent(QEvent::MouseButtonPress, QPointF(5, 5), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
